@@ -9,11 +9,13 @@ import argparse
 import sys
 import os.path
 import importlib.resources
+import json
 
 import yaml
 import texttable
 import jinja2
 
+
 import cfnStack
 
 _region = "us-west-2"
@@ -178,6 +180,7 @@ if __name__ == "__main__":
 
         with open(this_config_file, "r") as stack_config_file_obj:
             stack_config_json = stack_config_file_obj.read()
+            stack_config_parsed = json.loads(stack_config_json)
 
         if len(args.only_profiles) == 0:
             # Take all Configured Profiles
@@ -194,17 +197,21 @@ if __name__ == "__main__":
                                                                             mprofiles)))
                 sys.exit(3)
 
+        wregions = stack_config_parsed.get("regions", [_region])
+
         for wprofile in wprofiles:
-            action_tuples.append({"stack": wstack,
-                                  "stack_cfg": this_config,
-                                  "profile": wprofile,
-                                  "stack_config_json": stack_config_json})
+            for wregion in wregions:
+                action_tuples.append({"stack": wstack,
+                                      "stack_cfg": this_config,
+                                      "region": wregion,
+                                      "profile": wprofile,
+                                      "stack_config_json": stack_config_json})
 
     logger.info("Requesting Install/Updates for {} Stacks/Profile Combinations".format(len(action_tuples)))
     # logger.debug("Requested Stack/Profile Combinations.\n{}".format(json.dumps(action_tuples, indent=2)))
 
     result_table = texttable.Texttable(max_width=160)
-    result_table.add_row(["stack", "profile", "aws", "stack_valid", "changes", "action", "f_triggered"])
+    result_table.add_row(["stack", "profile", "region", "aws", "stack_valid", "changes", "action", "f_triggered"])
 
     should_break = False
 
